---
title: peering
---

Peering with burble.dn42
===

This page provides the information to get started on peering with the burble.dn42 network.  
burble.dn42 is a set of global POPs integrated to the [dn42](https://dn42.us/) network, and new peering requests are welcome, whether you are a new starter or already have an established network. A description of the network is available in the [about](/about) page.

####Peering Requests

Please mail **dn42@burble.com** if you'd like to peer with me.

By default, I'll configure a full transit connection with you which could mean I end up routing traffic over your network, but just let me know if you'd prefer a different peering arrangment.

At a minimum, I'll need to know the following in order to establish a peering:

* Your ASN
* The public address of your host
* The tunnel parameters, e.g.
  * Port number, if using wireguard or OpenVPN
  * Public key for wireguard or IPsec
  * Any special config you need that is different to my defaults
* IP addresses of your end of the tunnel
  * Typically these will be a single IPv4/32 and IPv6/128 from your DN42 allocation

#### Residential ISPs and Dynamic IP addresses

A 24/7 connection, with static IP addresses are the norm for DN42, and by default I will add firewall rules to limit tunnel traffic to your specific IP address. If you are connecting from a residential ISP or otherwise have a dynamic IP please let me know so that I can configure my side appropriately. If you don't do tell me, the peering will stop working when your IP address changes.

#### Supported Tunnel Types

I prefer to use [wireguard](https://wireguard.io/), it's simple to set up and just works. I have experience with each of the tunnel types listed below, but if you really want to use something else, just drop me an email and we'll work it out.

* **[Wireguard](https://wireguard.io/)**

   I use a random port number and unique key for each Wireguard peer, so just mail me to confirm the port number and public key.  
   Endpoint names and IP addresses are detailed below.
   
   My wireguard AllowedIPs are:
   ```
AllowedIPs=fe80::/64
AllowedIPs=fd00::/8
AllowedIPs=0.0.0.0/0
   ```
  
* **IPSec/GRE**

   IPSec/GRE is supported for peers with static IP addresses only.  
   IPSec public keys for each host are listed below.  
   X.509 certificates are supported if absolutely required, see the [Certificate Authority](/home/certificate-authority) page.
   
   My preferred ipsec parameters:
   
   ```
keyexchange=ikev2
ike=aes256-sha256-modp2048!
esp=aes256-sha256-modp2048!
ikelifetime=28800s
lifetime=3600s
```
My IPsec implementation is [Strongswan](https://www.strongswan.org/).
   
* **[OpenVPN](https://openvpn.net/)**

  By default, I will configure cipher aes-256-cbc, with a random OpenVPN port number and shared key.
 
  A client/server configuration with X.509 certificates can be deployed if required, see the [Certificate Authority](/home/certificate-authority) page.

####Allowed Traffic

Only the network ranges will be forwarded through the DN42 network, all other traffic will be dropped. 

**IPv4**
```
172.16.0.0/12
10.0.0.0/8
```

**IPv6**
```
fd00::/8
```

BGP peer addresses are more permissive to allow for link local or non-DN42 IP addresses within the tunnel, but these will not be forwarded through the DN42 network.

#### BGP Configuration

The burble.dn42 network is divided in to a number of BGP confederations
(see the [about](/about) page). The confederations use internal ASNs that are not
valid on DN42 and the network is presented as a single AS using the assigned DN42
ASN (AS4242422601) to external peers.

|||
|---|---|
|**Network Name** |BURBLE|
|**BURBLE-MNT**|dn42@burble.com|
|**ASN**|AS4242422601|
&nbsp;

The burble.dn42 network uses [bird 2](https://bird.network.cz/?get_doc&f=bird.html&v=20), and the following features are supported:

* Multiprotocol BGP [RFC 4760](https://www.rfc-editor.org/info/rfc4760)
* BGP Large Communities [RFC 8092](http://www.rfc-editor.org/info/rfc8092)
* BGP Confederations [RFC 5065](https://www.rfc-editor.org/info/rfc5065)
* dn42 Route Origin Authorisation (ROA - see below section on Route Filtering) 
* dn42 [BGP communities](https://wiki.dn42.us/howto/Bird-communities)
* burble.dn42 custom [large communities](/home/bgp-communities)
* burble.dn42 [Routing Policy](/home/routing-policy)

**Route Filtering**

Incoming routes are filtered according the rules in the dn42 registry (data/filter.txt and data/filter6.txt).

Additionally Route Origin Authorisation (ROA) is implemented with updates through RPKI,
using [dn42regsrv](https://git.dn42.us/burble/dn42regsrv) and
[gortr](https://github.com/cloudflare/gortr). This means any advertised prefix that does
not have a corresponding route{,6} object in the DN42 registry will be dropped.

The DN42 ROA data is provided as a public service, see the [Services](/home/burble-dn42-services) page.

Generic Allowed Prefixes:

IPv4
```
172.20.0.0/14{21,29}, # dn42
172.20.0.0/24{28,32}, # dn42 Anycast
172.21.0.0/24{28,32}, # dn42 Anycast
172.22.0.0/24{28,32}, # dn42 Anycast
172.23.0.0/24{28,32}, # dn42 Anycast
172.31.0.0/16+,       # ChaosVPN
10.100.0.0/14+,       # ChaosVPN
10.0.0.0/8{15,24}     # Freifunk.net
```

IPv6
```
fd00::/8{44,64}
```

#### Testing

Within the tunnel, hosts respond to ping and traceroute, but also have the echo (port 7) and daytime (port 13) services enabled. These can be used to check the tunnel is up and configured correctly.

```
$ ping fe80::42:2601:32:1%wg0
PING fe80::42:2601:32:1%wg0(fe80::42:2601:32:1%wg0) 56 data bytes
64 bytes from fe80::42:2601:32:1%wg0: icmp_seq=1 ttl=64 time=4.44 ms
64 bytes from fe80::42:2601:32:1%wg0: icmp_seq=2 ttl=64 time=4.52 ms
64 bytes from fe80::42:2601:32:1%wg0: icmp_seq=3 ttl=64 time=4.96 ms
^C
--- fe80::42:2601:32:1%wg0 ping statistics ---
3 packets transmitted, 3 received, 0% packet loss, time 2003ms
rtt min/avg/max/mdev = 4.445/4.643/4.961/0.233 ms
$ netcat fe80::42:2601:32:1%wg0 13
Sun Sep 23 09:57:26 2018
^C
$
```

Once peering is established I have a BGP looking glass [here](https://lg.burble.com/) (public internet link) and global route [collector](https://collector.burble.com) which can be used to check routing.

---
#### Network Information  
The burble.dn42 is fully meshed between nodes using wireguard tunnels and VXLAN. However, the network is configured as a number of sub-AS regions within a single BGP confederation to allow for regional services and to reduce the number of iBGP sessions. See the [about](/about) page for more details and a network diagram.

The internal, confederation ASNs documented here are *for information only* as they are not valid DN42 ASNs.  
When peering with burble.dn42 the DN42 assigned AS4242422601 should always be used. 

|||
|---|---|
|**IPv4 Prefix (Services)**  |172.20.129.0/27|
|**IPv4 Prefix (Nodes)**  |172.20.129.160/27|
|**IPv6 Prefix**|fd42:4242:2601::/48|

###North and West Europe Core  
Internal ASN: AS4226010150

####dn42-fr-rbx1
|||
|---|---|
|**Location**|OVH, Roubaix, France|
|**Alias**|sunflower|
|**Public Hostname**|dn42-fr-rbx1.burble.com|
|**Public IPv4 Address**|91.121.7.182|
|**Public IPv6 Address**|2001:41d0:1:5ab6::1|
|**Tunnel IPv4 Peer Address**|172.20.129.188/32|
|**Tunnel IPv6 Link Local**|fe80::42:2601:36:1/64|
|**Tunnel IPv6 ULA**|fd42:4242:2601:36::1/128|
|**X.509 Host Certificate**|[dn42-fr-rbx1.pem](/home/certificate-authority/certs/dn42-fr-rbx1.pem)|
|**IPSec Public Key**||
```
-----BEGIN PUBLIC KEY-----
MIICIjANBgkqhkiG9w0BAQEFAAOCAg8AMIICCgKCAgEAsOVLqqSRI5c2xrOiUoi9
6RQYFQtCUlSWrTxIMIvm2UxFUQKILh3XeegEgP7473yStsQ/Ug8HfD0zP5DDeNfj
I0pO/qVeQFICVSO18vWiH/ONUn3cMGIdMnHeP28Yz8wESfuMLUD6YkyEARkVF4Og
mZ96GvKkm9IxYNjMdcDlqr+NOOMrHv+iOQR/CxUWlQYozqAtjljxv+dJxf8w95HS
r0gChtIoruroPuXi3t5F/G+1qPPphqUKF8N3LNNtqMbRmotgu4y2Oa6oQcqK+NcP
wPoH1syA+JYGnzFSPJRvV7G/UalpwSyd/UeV/orx24Vz0C135scRAQA8CX3a458W
gui9QDpAyd3zo+KFaLTpbyt/KAlrC1FxzKrCTiCYiXYwWwCyv7yYEDONVbFZ/Ujn
r+OmpcA3sLcrueA5miCtwB6PAgm9gEyMgsfhZtQTcVZk6L5lCPab2MH68Ve9T+vg
ufruW6D4sahym/uNhPOk9rEj1TYCX8qqCWK2HjFTaScV30pRQ/6jjaFE6ip5xIO7
hiCmi+CGgKyAg84EDQNKB8cmuF4fFMkC4dogTvF9USFOhv1YhsrDKzWLIAgc721f
Jm0DIOPKHqxNzjabKLG0jxw9CQbaKNWp9f+Ne8/DBL/lhU9xRFSoGN9HIFnMFMP6
S/cZLXifpcoJzseYdlzsyD8CAwEAAQ==
-----END PUBLIC KEY-----
```

####dn42-uk-lon1
|||
|---|---|
|**Location**|Inception Hosting, London, UK|
|**Alias**|bode|
|**Public Hostname**|dn42-uk-lon1.burble.com|
|**Public IPv4 Address**|185.121.25.242|
|**Public IPv6 Address**|2a04:92c7:e:bd2::e6b9|
|**Tunnel IPv4 Peer Address**|172.20.129.187/32|
|**Tunnel IPv6 Link Local**|fe80::42:2601:35:1/64|
|**Tunnel IPv6 ULA**|fd42:4242:2601:35::1/128|
|**IPSec Public Key**||
```
-----BEGIN PUBLIC KEY-----
MIICIjANBgkqhkiG9w0BAQEFAAOCAg8AMIICCgKCAgEArDHgvtB06KEm15gix0kT
SsR09J5gZ8CNbnwVzXkn7l+uaBAZygvQNetEYysu0lFwaePOfBn3Qs9beCgfhVVW
RNElSwZGvOybpqM9dCIhvMC7ekAJie43KBaAs+t1P2dIQrhaOl9ZOo2BbkU0GCyO
/tB19ICWLgWibcmNVhhWiywsi1SctDJBKRAgMLFwpgQCU60Czv83pi8Jq0taEpCS
RMN65+E613Jb778ZAhtkHfkQr16VqF0QSoTgTovgeJxf35ly/CxPR3d1g7vvgW2U
yhFSXikUTs3AR/5Fue9DHnDOYstdJhPKDt7JrWSxO+8fJXz1WuenXXHfX+A20o/p
g1tvatRQUO0lcVuQLlPSjBJkkjyn1JduRWVHNVeRMKLqpSaXpl2sMhyyNuiU9Dtj
p/PmdonX5afqaynHTeSBf+uGMqPVbz6VCUvOM8ZUUG3YJW2YS206MZnwQu5P7IhL
R+otPaFLRnElUZKwaoAxxv+XcFaE4XRRIRG8V0jazDUSrBlzG+HfUFe8yKhfIj4E
znzUMHxQmbk95+WlPJO3fawLjqcMlc+9DjDlasHPd0iuBP69abjnnpiWtruZ7R1S
wtgOlenWhFMe4CLf7h7359aYmgyOvwf7/gWMrU2KseTu5YRXMKN1sejJEzUQevfL
bf+HCl44S/pxswgEmXuxL7UCAwEAAQ==
-----END PUBLIC KEY-----
```

####dn42-no-osl1
|||
|---|---|
|**Location**|HostHatch, Oslo, Norway|
|**Alias**|seyfert|
|**Public Hostname**|dn42-no-osl1.burble.com|
|**Public IPv4 Address**|185.175.56.155|
|**Public IPv6 Address**|2a0d:5600:30:18::8c3a|
|**Tunnel IPv4 Peer Address**|172.20.129.176/32|
|**Tunnel IPv6 Link Local**|fe80::42:2601:26:1/64|
|**Tunnel IPv6 ULA**|fd42:4242:2601:26::1/128|
|**IPSec Public Key**||
```
-----BEGIN PUBLIC KEY-----
MIICIjANBgkqhkiG9w0BAQEFAAOCAg8AMIICCgKCAgEAxWT6No65elo9+0JXxqsB
BGGinuFpELS6hphzqr/4ctv89Z0BmWOjWxIUXvWboW/qFnVbAeeVVwbERUDIefnM
hG/Iu6SkaRYahoEG862FfTiucP8Dqbs3LDOo6ZvbvlBrgC8f45cxzLtiY+HIvjTy
SR5VeGLucjicjrupXtYTRrkjNEA+jGiZVKASmiIC760kyrOTQ2/KpEPv5FC8vU5w
byEvO47ZrLA3nABBKHHKNBsD6GmN332UAyTon+cdJ8wyTEiYYIylX5K4sWaARQPg
aAbGBDUDoXw49JNAlgAosYwMgX8mmuNBRHcHVfw5BoHYyJEuaynCM4h+jmvUeEvY
33OBKjsYwriWIeL3Uv8U9K/YfZMW2C7Vovn++TTW9MxgE6ID3+cvYrKmlK1G75hq
oXZyVn3JAkDonXj3T2cGd6D5Q3wUcmn4FA2hPsk9AmP5BcFLea/0cB7BV2jOCqUB
cydm1zl/Cx744WAcgs46siXsP3T74gb81LUpG1d3tgm+Tro5efnZcwWwUhwpWamm
rMWBfiEHgBDv7a6Xc1JwP0V6uCRWRhkJQ9ogdtKE7nfGWjqrEv00bOepaMQQCPM/
oflRdgswnHa7Qf5J9eKH8PJyIft4Ms3iSQsYwUi4nEhkTJ4BWDx6gQi6hZrTGLqm
d7h5/E4AP001ss5jWUpmMfcCAwEAAQ==
-----END PUBLIC KEY-----
```

####dn42-de-fra1
|||
|---|---|
|**Location**|PHP Friends, Frankfurt, Germany|
|**Alias**|abell|
|**Public Hostname**|dn42-de-fra1.burble.com|
|**Public IPv4 Address**|176.96.138.245|
|**Public IPv6 Address**|2a0d:5940:1:c3::b35c|
|**Tunnel IPv4 Peer Address**|172.20.129.169/32|
|**Tunnel IPv6 Link Local**|fe80::42:2601:31:1/64|
|**Tunnel IPv6 ULA**|fd42:4242:2601:31::1/128|
|**IPSec Public Key**||
```
-----BEGIN PUBLIC KEY-----
MIICIjANBgkqhkiG9w0BAQEFAAOCAg8AMIICCgKCAgEAuHdbN5eXkbovWwdHx2Xc
dxk21AbK4l88hKBTKfQF0Y9ro+TG6qyAUA+cIOeFmVvI2Gyk/pPx4DZavcfT/hl/
60Omj0OjuKsgho4No2OxRizj98l2uWJAZyc8P0D6pf4M1LQbCN1nDQTadY2f/+PQ
JG7WP+YHNzcHE7xP8ypZwMhuVrldMLmYgLpw8zBRTjDng01QAjXSBdDVFrTz0Eok
SsNe2ikL7pV5Tha4AwM2XeQBSqElS8OLyBh20HIF0TtDViupeCMMy/drwQw/iyoB
RP/UXlLpXt8zWuEQ3aPVA2TA5CzJm6JExnnZFusUj0IbOgA5HxESsFZhMs8GJAcA
bENM+XXjT8IzNw/PxJIxwLYp1vTVDTBTs6+YrQOlRl06cdMaMRx45CjEpQT0GIoM
rq4oW4Scn1W+/Qw90CiWnAHi8sj1F3IFfsm5ld8qI4aMRbMPEHurnJGrtWZ7QYPT
Nt6Uk54asyqvhx5Osa/MLAMQ5+cp4tlIfq3CByMr9Ih+1cCbbcO9alLozTgAeSyd
gUcbmJ6LpDkc7uhPRUfJ3tbDONxyFp4ERmuWVu2n3709p51jy/FaZQamPNtfp7We
rP0Ksp/Luq3uaKRshp5AY1f317CR7KpkQ/XOjc7BEcu7NJWBa91PT45M3eIyBZFS
KcOBD8LmjW9LfIAOinpYihECAwEAAQ==
-----END PUBLIC KEY-----
```


###Eastern Europe  
Internal ASN: AS4226010151

####dn42-lt-vil1
|||
|---|---|
|**Location**|Time4VPS, Vilnius, Lithuania|
|**Alias**|cosmos|
|**Public Hostname**|dn42-lt-vil1.burble.com|
|**Public IPv4 Address**|195.181.241.93|
|**Public IPv6 Address**|2a02:7b40:c3b5:f15d::1|
|**Tunnel IPv4 Peer Address**|172.20.129.189/32|
|**Tunnel IPv6 Link Local**|fe80::42:2601:3d:1/64|
|**Tunnel IPv6 ULA**|fd42:4242:2601:3d::1/128|
|**IPSec Public Key**||
```
-----BEGIN PUBLIC KEY-----
MIICIjANBgkqhkiG9w0BAQEFAAOCAg8AMIICCgKCAgEAxHXG1p8nVNCO7neCtysG
U3pGUYblBnrtBPR90pgytIcbcllWU0HmkI5Ez4tdpKqBdZ+cqs7uxpo0/DNlAp0s
6gGS2b5JMV2nZEL+u8AtHCtOCrjUDlMpcY96WvOia8Dmi/kw0GPnxiuvDzJU+pJ8
tRy+UnrN+PGjYrXPv2KnjeexGtp4pXee8d9D8o4PPfnSUr42B4OOjyWfDceOggwV
L83nUIvKJGmJOmwHPpf7wedaPD2sKNobSLuoc4XZ6Hn3SQ980cDqDYqjhYahLifl
7u16O4JtSea74WNST4LM1MM1r/yddEPlk+th3GvkZxv5RcUbMKqtiowfSubduUPM
79a9o7BeJLoj444sStJWB1Yu0pPmYdJsQ+isCUiTkNfFjwLtj69mcQmG6YYfY8vM
p5ADgpTzEMlN7i/l7SLrFDZKa2obYdY9n6CTPud43g+P9r31DF2qXdFvbqxFQroG
UG8GhMvvltUxnxuB5ne5lJBNAwevWoc3jq746BFPqkT1/KI5BDBzNbv55dk6AZy4
Q8zw+KbbW7O6+zmk4jD3D9rZZU5bi7h6eZL/TaNIR8zVherAZk1ZsyQkHPoymnNQ
nAPpGHGblOo3PoNXi9O0GRaj4Y+O84c2FCA43PS6yChtYf5R2xpDdMG/fgZvZDFM
oyK7ejnrTzb42sb/RDkqsqkCAwEAAQ==
-----END PUBLIC KEY-----
```

####dn42-at-vie1
|||
|---|---|
|**Location**|HostHatch, Vienna, Austria|
|**Alias**|tadpole|
|**Public Hostname**|dn42-at-vie1.burble.com|
|**Public IPv4 Address**|185.175.58.235|
|**Public IPv6 Address**|2a0d:5600:31:7::1|
|**Tunnel IPv4 Peer Address**|172.20.129.185/32|
|**Tunnel IPv6 Link Local**|fe80::42:2601:39:1/64|
|**Tunnel IPv6 ULA**|fd42:4242:2601:39::1/128|
|**IPSec Public Key**||
```
-----BEGIN PUBLIC KEY-----
MIICIjANBgkqhkiG9w0BAQEFAAOCAg8AMIICCgKCAgEAxuPep6dXqTHypWcYqZH8
wMS6V+EF0BaYfEp47U6Df8tjuRigcrmxMp3KeDYohP14eUN/95DQv+3FZAKZJR1O
jsC7SFJKiBlkW7tyekkU8E/t/TKjauvacpxoOn7md5w3J7Rcay5IqfUTEpqJz3A2
vT6K4oDNsWxkACFFlkkLMxwuPyhuvpJ35Hh64HwnIrmtsIFaa5UET8hOBEqm689Z
9iTGmU6KWhOHqWYU1F0fdkdVqKdwfy1lqByJfvMbJaMp+tawchaQFQHRAuOyvNfu
TkwkFBd7tDjY3UXrgRumFE7WG6Q/0afMRBTjW083jhGHYPx+VezTmRqnJn0ic0ZD
qfiX3cUWc8XaRcECbjXMZ2uEEjowMv2lAKIgD1+km7HLY5BRz2uolnl70bLpZEyI
LFexsvrBeJbpXJPTuLhEGPnm7/TCh1CifZmw+Q774l3VR2WP5r9+mhqa/LAi2hWJ
6scAozF6j7v5cDNYvCpZgRQZvwW+fogeIScVjmkCVQS7gFanu1UUtgEefd+ewhoM
petSGcokf9PfAhrmdPFmA5guPNVBXHnDZ9UrCW69X6G3ffFmMQ/K+wQDrfqThXh4
pUJBVhy8NOYwjm43AaELUADt/Wotq6Sg5uqxS7HZXc+91gl32arz2eygdeJIkH65
3WB4gfJdprKb9mEJTLjc+p8CAwEAAQ==
-----END PUBLIC KEY-----
```

####dn42-tr-ist1
|||
|---|---|
|**Location**|HostTigger, Istanbul, Turkey|
|**Alias**|virgo|
|**Public Hostname**|dn42-tr-ist1.burble.com|
|**Public IPv4 Address**|185.181.210.90|
|**Public IPv6 Address**|`IPv4 Only`|
|**Tunnel IPv4 Peer Address**|172.20.129.179/32|
|**Tunnel IPv6 Link Local**|fe80::42:2601:23:1/64|
|**Tunnel IPv6 ULA**|fd42:4242:2601:23::1/128|
|**X.509 Host Certificate**|[dn42-tr-ist1.pem](/home/certificate-authority/certs/dn42-tr-ist1.pem)|
|**IPSec Public Key**||
```
-----BEGIN PUBLIC KEY-----
MIICIjANBgkqhkiG9w0BAQEFAAOCAg8AMIICCgKCAgEAx6zPdoBSYtdAHmA6tH4e
+pCUyJgj4X4ijAMYHDS6w9iQTPTeBJaIDZfQmqiBsGejgoNeTMQwbNxiXWFvXjtx
GeSXGTHRnVJNCRKU2V0C+jzeEAa1nb8ykOzzRijLRE0U5an5JOEKjI4BCnJ7uYmy
EgySkEhwJtwF7sukISpkwG5gpAzVYmBWC6N9JGrYjp1eqmefLjbNSLx0hox0s24F
OknnVqeUZfiGRW7aBxM8a6ytWeG3W9NOy8qoyb05gUzNK6Tc2bE5/2DAoT2anW9v
Qq7C7WU93JR36Zpm2msh4xMkWMsbPP3GAvdsEp1CI3UjuEjIM//3YqPM6qURIA+f
L5tZBadxwVn0gONFFhn2/gCoAKyv7MNy4KBZmM2Q6OfWyDiYRdllUSu6XNtZcNgC
34NmQm/pbev4DcHCT0F58iwqL9G3P1jarPnR+fbqZAVW5PScXE4m5FOjH1a/HMTZ
tlL/4/ZDp/spO+bxyCRhN7nyKU3AZokHBwM1iZMndVGUW7fQqXK1nPPL1W7JCbYp
zw4kp44u8DnuEUR4071gWClG7bs6wwwi9uUlTH9BGjSW7oXmVjvG0jNbAaPonj/U
zp9jFpRykpdySL7NKlkG+JaBSeV502wf6DpQfzmKRwd00sRVUxCrD84t9FWParO2
oMMfl6ByjhYCn1xbRXnJjr8CAwEAAQ==
-----END PUBLIC KEY-----
```

####dn42-ru-mos1
|||
|---|---|
|**Location**|JustHost.ru, Dataline DC, Moscow, Russia|
|**Alias**|cygnus|
|**Public Hostname**|dn42-ru-mos1.burble.com|
|**Public IPv4 Address**|176.32.35.228|
|**Public IPv6 Address**|2a00:b700::1:1e0|
|**Tunnel IPv4 Peer Address**|172.20.129.184/32|
|**Tunnel IPv6 Link Local**|fe80::42:2601:22:1/64|
|**Tunnel IPv6 ULA**|fd42:4242:2601:22::1/128|
|**IPSec Public Key**||
```
-----BEGIN PUBLIC KEY-----
MIICIjANBgkqhkiG9w0BAQEFAAOCAg8AMIICCgKCAgEAuHwq82nRB+aoAiDAHkU+
b3gAFYY8Ljh491PDAReutfIS1eMkeKbn57OEYP7ZeFh2o+kpYl0VK2Ib5MBzgiEC
OwRX4ExqiS2B2lXcVegYmxLqUMiaGx7AXfDxzjTxNnhvq9o78MJu344qRb7+I+sD
FYWbbWJLkM5w+MYfsPjUWcGWOOF2+2dpyaM76W2gwpiFMfCtOLHAC+7itmrZcFHC
CcknAV9TLbJj2Ddi2/eb2lU9rO3jNnz+RDabXjfmGcBb0o3z1gs5LKctKwGfqCyp
hcAe5f7E2T2nrsMf9vyaEEtD0GJ/l7Pq0Yd6JII75yE9JcE07w3pbGwToOtRMeIo
/kQlHoTaR0o4Z6MdDhp3tXra3E6m1szpImLbaVMMX48r56VnjddweWYssvCc5O0P
35DxcTuHkfCSis/D3IjXxVJmttxc5I/yiEeZUYSMna+STwHCuJKSl+IRCEnFRk/T
BYl6PCVBs85x3ydeO+tqidng86Np96EiBPub4PdZtmRhurylub91ZkIe3zxA1CpT
xJcAfvhxVUpnpjI347ODjg3jvE9v2gJEqL/C/ggD+T+ipobO8jsaw52gI10/3sEH
5hivVvpIOj5JVsGWnn75Fqa4Yu/mqln6eQ4x3C9fx/bPCDGVN1H4GCDiTEI1IK22
ikT0S9cs/+Mr8d2j8cgBM9cCAwEAAQ==
-----END PUBLIC KEY-----
```

###North America (East Coast)
Internal ASN: AS4226010021

####dn42-ca-bhs2
|||
|---|---|
|**Location**|OVH, Beauharnois, Canada|
|**Alias**|draco|
|**Public Hostname**|dn42-ca-bhs2.burble.com|
|**Public IPv4 Address**|192.99.2.172|
|**Public IPv6 Address**|2607:5300:60:33ac::1|
|**Tunnel IPv4 Peer Address**|172.20.129.167/32|
|**Tunnel IPv6 Link Local**|fe80::42:2601:2d:1/64|
|**Tunnel IPv6 ULA**|fd42:4242:2601:2d::1/128|
|**IPSec Public Key**||
```
-----BEGIN PUBLIC KEY-----
MIICIjANBgkqhkiG9w0BAQEFAAOCAg8AMIICCgKCAgEA7HqZAmqnN4fQprr+4cKr
RrPfOGmaJBYr7eY3rylIGqBV09xxzkjG2ogd62f5Em9mWqX8q4Q71zKt+G3iUct0
mMIEokWGTHfbJyiZPmnFPn3v4fbWowCK/C71p+spk+hUsHwyNx4QRn34B+Cn+jRi
uxvxRYuugKVepje5vbF3qeKJMQSzui25KSigBBBt0NxmtSgImfyLPd+kqjLKtJYf
NFbuuzhOnzEaEUunoSeXYJNL195KDq7M+ue+HYwdnw0/DaqxmwB08a9bbAReW9l0
J/DEGARRqNp4Sz30DQYpfTAl9mQjhE76WLHIMR4tJQvfcrUoetYXmISJRD0Ky99K
KHy4JBYhpDxg7+jr6MrmJx6yuypzBd12RNZamY7qjquLRIPoxvONDkpxffnw63Bg
H1k2b0Fmrj+BIe6aPIcxGKVKVXzs/ffXCkqbqU5ZHi5GQzf7JKDaVrvucaRvonpg
zsQH0nPTR+PkCL6vmAtAzUVLtRXjO2P5Np+7R3IXi+3McAQRmb0zAdhp56b+CLbj
vseYpScW1qjBa8ZVIqQNln2XhEWBCzx7iTq1RLa19V6IuWD8gVkl2V+OtDJveySd
+Gvt6MjlOcPRvK5GOvUzts8GQu5kD1BXyswbb1aXNvjlEpeRAzpUPGusJgRyOD1I
q2u9n/wc7+HlZasbBddgp6sCAwEAAQ==
-----END PUBLIC KEY-----
```

####dn42-ca-bhs1
|||
|---|---|
|**Location**|OVH, Beauharnois, Canada|
|**Alias**|comet|
|**Public Hostname**|dn42-ca-bhs1.burble.com|
|**Public IPv4 Address**|54.39.20.247|
|**Public IPv6 Address**|2607:5300:201:3100::3c20|
|**Tunnel IPv4 Peer Address**|172.20.129.177/32|
|**Tunnel IPv6 Link Local**|fe80::42:2601:25:1/64|
|**Tunnel IPv6 ULA**|fd42:4242:2601:25::1/128|
|**IPSec Public Key**||
```
-----BEGIN PUBLIC KEY-----
MIICIjANBgkqhkiG9w0BAQEFAAOCAg8AMIICCgKCAgEAs59pjaNVMRuhKSARl5Pq
++TIPPvys3DxmDAAkTtIkHJljIACzLto19t0Na2QPrxiBRUI6WHnx6G0LECLMcU/
lF1VI6XjAhFGGo6rYFisAG8pQYt7dTY4hZ5LthEf/yKk3dK9oqQIX6A7P6naYQN9
8ZXwrJS+cEe7Wjlcn1tXk7N4uD2+sMKe7AXKpkMj9wDgwZhA/jlg1Jqmoy41b/ic
K5R+Wp0tlm0GoY+vwHi7E8zgMiDppY3UWRvvZDrmmMO+Tvmka+QZH2ypuZZ3kayi
pPNlyktwmOpiA0QGQAcpLJDjY6tdrI2+mowA4MSgWbvjBh5/32HSGT0Z/vKuY1mm
x2YsZDeiFzjhvnVvDSkme9WW2WGFghstw1vPXj895hcb+VE8h2Z1ppyFURdvg8oY
xVaaud0ol5vRdo0RSJy03428jx2wgk+doOLb1hkz30xv1FgqYXCN91r5aRykHn4V
5IL1kASextMSPpRW19Ci0mQrKM38yqsyJXA/Kw6vYtBmt6XLdHMSj5Vuv3jLHGED
RonMwehclBALgl4ysD6YNkXRWb+Wb8gH/1OFsIILaTu/T+2/3Ess3JGbuKkHiVXC
6RQoizzoIA4UHHZiUS4Hrw6a1+v2BdO6WhllO4teIS4uuJCXlJa8cE0+PYELMy8r
K3py8LhdABVHyyDvtrqB1y8CAwEAAQ==
-----END PUBLIC KEY-----
```

####dn42-us-chi2
|||
|---|---|
|**Location**|VirMach, Chicago, United States|
|**Alias**|markarian|
|**Public Hostname**|dn42-us-chi2.burble.com|
|**Public IPv4 Address**|198.46.223.227|
|**Public IPv6 Address**|`IPv4 Only`|
|**Tunnel IPv4 Peer Address**|172.20.129.171/32|
|**Tunnel IPv6 Link Local**|fe80::42:2601:2b:1/64|
|**Tunnel IPv6 ULA**|fd42:4242:2601:2b::1/128|
|**IPSec Public Key**||
```
-----BEGIN PUBLIC KEY-----
MIICIjANBgkqhkiG9w0BAQEFAAOCAg8AMIICCgKCAgEAu8ioUXZTivQM+fp3xVt3
zuAxyRf95EbMA3wLBDLROh/R18WCJKUPHRsBaPhtOk/iem3cpfrQ6/I3tgTv3FaE
lraK+X12x1N5hB8SylcdI7dW2KHPj46n3OGtzrn0kjuogpTdcKVACn3KsqeP+Uro
z9cTJS6ajtuaCYN0X27IwFE5Jwl9d1ZC87rfgqkfHFfICkCsQi64BhVEzCeAYmYw
WIa9rgUba9ZYjkJljQQkZFIshTEdPHFPRb3kYNNJlMg5h/1srE6Lxi/Iv1ZueG1x
5IjYRU5UO1ua+O/nO9kLo6Q/OMTcvZn1a/o54YwvFQtytDy87U4Y58GHdWuMGZfo
dDvDTfrSKyj5CleNHMEpkci5Eq3obw+Wy537MztyjG0EPZ6LeCIR8UlxxUROq15W
VkXUBOSuqsb8+i2wt+gAP+IH+XTAu/8lpQ2TAOREQHHjMmY4NLBQBFvzBePswVLb
S4mLz7fuAJXkB4u8mcBUBFiUl695WQe1mEjnBYnHqjHmmXPU4O+1eryXu7YZm+Ni
01yVtIV3NUolaEiZozzDJc5XPiMgcw/DRLA99+q0l/CSfu+4S3NbhCpN8W6PGDLn
vOH+kqbBYdu5TmdmO+epwXyznZ7urNpI/C6wUNpE4AoUdqT8W4K5/RVdP+9KD1MU
WqiODjvRqWsi5F846Jho9ScCAwEAAQ==
-----END PUBLIC KEY-----
```

####dn42-us-mia1
|||
|---|---|
|**Location**|Virtono, Miami, United States|
|**Alias**|segue|
|**Public Hostname**|dn42-us-mia1.burble.com|
|**Public IPv4 Address**|93.119.178.120|
|**Public IPv6 Address**|2001:550:1d05:30::58e:3ef3|
|**Tunnel IPv4 Peer Address**|172.20.129.183/32|
|**Tunnel IPv6 Link Local**|fe80::42:2601:3c:1/64|
|**Tunnel IPv6 ULA**|fd42:4242:2601:3c::1/128|
|**IPSec Public Key**||
```
-----BEGIN PUBLIC KEY-----
MIICIjANBgkqhkiG9w0BAQEFAAOCAg8AMIICCgKCAgEAuI06qjXjouGV8x4kTQGE
vkRsnG4FA2ex+PO/3P36CXLY3/60Ff/Ghg0klhMqb7EZI/IycQPdOdWjefntDeXn
hccN26pFr7IOQhRZf2M4TSDO7vOH3ayssDInq+xstpQe56S3FCpXtAPUoMmIyVFT
SIfS7D3MY8Fl8U2IqF6BBPRpbtQNScHrgr23wn4enYjRAqhVLNkMZDIMXbsLQF13
GuHM+yeTsv5t6lIs9BwsNv3t7NP/XBbv6MLCXr09n1N+jmLle3w9Ygu9PO48hkJH
eF8TUaaThZPySkN2az81HxdBVOGQYP5xgOBUJ83+To6CU2bgxQAECOg7U71NwOrZ
oU69ML9tgU7Fxz36F9s+V5GL8MezzJBtgXyxhTFnxbyn4qy7k+Jem58B3pl0bcSi
s5YpxTGUMyVn6TkbbMQ+MaIzLiL7NFWxpJvaMXYBnIZs7B1iZhPZgqC99lPmkp5X
630T/Wv/bjuU4IPToNS0ECNigka4jWivUBOeEHMdHljIfzpYWOMiiBBV/Dpx5exW
EGFijWp4GI2Q++D7tWxO2hpO4vMoQzolUV6PkwzElyAntifqv+HgYgdUkQTNPb3q
DIBTMivZkCKDr2Xpr35SNPkWTIJMZs2TULm/Dj8fAJbyrDKjhEvzPBNA4U+V7J0C
8qWq3tVJ/hKaYppndWd73NECAwEAAQ==
-----END PUBLIC KEY-----
```

####dn42-us-nyc1
|||
|---|---|
|**Location**|HostHatch, New York, United States|
|**Alias**|sombrero|
|**Public Hostname**|dn42-us-nyc1.burble.com|
|**Public IPv4 Address**|185.213.26.143|
|**Public IPv6 Address**|2a0d:5600:33:b::1|
|**Tunnel IPv4 Peer Address**|172.20.129.168/32|
|**Tunnel IPv6 Link Local**|fe80::42:2601:34:1/64|
|**Tunnel IPv6 ULA**|fd42:4242:2601:34::1/128|
|**IPSec Public Key**||
```
-----BEGIN PUBLIC KEY-----
MIICIjANBgkqhkiG9w0BAQEFAAOCAg8AMIICCgKCAgEAvfLD+quBVm3yBDPOxWfm
oqnX3ufAKlezT2/k95PaSLPYT/Gi9BG+JFimY90yj6pfMFHjCRycu3X4vETgNPCj
q5A8EBfiiEGqjsQ3ufpF44R0t5HE1ZzwfkEb+xQGzXmHsGW0WwfAKXBhW5S9muj4
svnDf4xPVDY8jtLB3il4su2ktz+3WPO/7JrjxFmRfYxt3znwGMv6hoSr1fdDSD1X
dHR9WmtRZyna4BEZbrNMnHkz2+yttuM8oVpei1/fW/v92niXLTje04nGgt+1jlBR
G2KzxJ6u2GJjMHL+SgVeKb8dNBcB05cbdqZX2Bwf/AAQEm2nC2TL/WdqKWE/aKAT
X5XdBncU67ARowyxRVc9J0AqSuqsLfV+Qfd0bE1Iayig+L3TjB1Qosxla6x11QT8
L4SbYibmMOPGmRATX0JXO8/ndf5J+ojNpQfu7G2coo3JaG724t+aa9qRrpiTsaBy
8ylYXNYEEBzfumCsERarLfgLPKxi/3u5MA2v1VUoQKd6jm96fqC90Opdr9dQ0L09
qdEChC554r+E1dguWe9SBS3rl9YQgnrsypsJoYujzJ/dnAyVAXBhVeYzB8H/GlAX
NNwqdu9G6duzsuWd27Q60ZgcLMwbcGO31LhbnJ/sxfD7y4SLmFtmDU+oAsC1iqIT
Psy2c3c+bHemzabTLv5IQHsCAwEAAQ==
-----END PUBLIC KEY-----
```

###North America (Central & West Coast)
Internal ASN: AS4226011021


####dn42-us-dal3
|||
|---|---|
|**Location**|HostDoc, Dallas, United States|
|**Alias**|lacertae|
|**Public Hostname**|dn42-us-dal3.burble.com|
|**Public IPv4 Address**|107.155.79.108|
|**Public IPv6 Address**|2604:880:398:353::1|
|**Tunnel IPv4 Peer Address**|172.20.129.172/32|
|**Tunnel IPv6 Link Local**|fe80::42:2601:2a:1/64|
|**Tunnel IPv6 ULA**|fd42:4242:2601:2a::1/128|
|**IPSec Public Key**||
```
-----BEGIN PUBLIC KEY-----
MIICIjANBgkqhkiG9w0BAQEFAAOCAg8AMIICCgKCAgEA2dgJHSuUFicSQpzfeuoo
3brR8au/XBhnU8d9AeWg7KMeoKFC/wajXDi0WUEuAbQ602ImXOU763jwUT2SfQMt
iKqerFJJGQn9oGAK6SoowzTsaoHBZexu6vNepX+FhuqXo20g73MzRPkq6Ud/UJmb
uUM6wggPgN/UAKBTe6KJ3Gz2g4DgTGc1LG5DIdnwDPmIYhXdwxJU8FrFH5O5F5/A
ZSm8RjWJ6o6yc7LfZ4Or/C4Ycdh7qXKRCew3yIhts4MUYMSpo7iAVen3t8KT6Bdj
OOIHpQVWeJhrwG/kill7Bcb+VZQm23va8fMAO1t13B6NSIXWr8x1RFTja/KgY7sC
yrioKntqdH3Z4Lfh8gOQ2DRo0yoyHEl4D4CxK0GRvysPNcO3HH3C0OfsrNqtM3lH
6vX1a/FnS/giS95H+nZ9jXzarVLZJq6dbsnk8fsgVOS3tiLNm940g/5Eh5Z0Nmwp
NGG2oea+ZiWmX3xem9JnV4uGN3nB+GguJ0mPaoY9AJzAvbJRvPj0SxdEyJZ/WZa0
HcoWMhe9sohw73rRpPEfhplZXd/fH+g5/HGDBXGpmA98upVGNcsga4zkOgNvYh3F
p2UcnkFJahbltifKAagSObFdbDlF7dYv3qTpxt5+TJj2PRBpqtb+KjQ/OPvJ1rDd
gwj6kVhdIoel1Zm/aOiW3okCAwEAAQ==
-----END PUBLIC KEY-----
```

####dn42-us-lax2
|||
|---|---|
|**Location**|VirMach, Los Angeles, United States|
|**Alias**|messier|
|**Public Hostname**|dn42-us-lax2.burble.com|
|**Public IPv4 Address**|104.168.88.15|
|**Public IPv6 Address**|`IPv4 Only`|
|**Tunnel IPv4 Peer Address**|172.20.129.174/32|
|**Tunnel IPv6 Link Local**|fe80::42:2601:28:1/64|
|**Tunnel IPv6 ULA**|fd42:4242:2601:28::1/128|
|**IPSec Public Key**||
```
-----BEGIN PUBLIC KEY-----
MIICIjANBgkqhkiG9w0BAQEFAAOCAg8AMIICCgKCAgEAt5NthwJQEiRix0gEfbl3
NNonA1xULr0lOSSNtau2QjxJW9aX73E/HH4BV05qenEgl0mC0+y4gzRS6yAZ/wVE
W71ApdgHaFUlerBeiypGb+ZknRQYv8BAT/YX6Jn9FC/GN0xlcaLmYsYloCB25MFt
PT+B67ENo2O42hoMwPP+BZgji6cDcnRiN+d5DXwhX90pqOF6CLy3mZt9PIXkU5u3
TclTd+h+qJo+liGgd18dvAPtvWLb95NbJyCZn51g3TGMT6nuGW2xuPUtQxjIwc7A
Ix2Shgotmz7Kiy5ezqnY3M+quy52U5PzBNMm7wThhPJNR6TkzASkKacEe53pxO9s
0wa+gSiiw6TgUcv8QbgtwdbkGbrW6gFY9jxJqSp6vIFcmSonb6C9tbtErMIFP4wq
wLpF3DW0EHrXxhcg99s2T+7/cKYMS+Z5QUK5D4YQbaDpBR58GCCkaRf9EM0pVdHO
mZbS0Fi/gP/XfFJxATya464cZlGgLpEp4LUxiDkeFEs5U0lHf90qr0rSw9ZM9Dy6
0x1b/0a3ABwPGu7BNvY7cd1bI6lpRfC9YALLyEjhbLG1G6o5xrCFu/gXPBDPmv58
H1aYtjBLdJKV0AQEICkRi4K01AooQp68dWKQympvAeWSb3D/Z8/w4udAiNXrzdMF
b2XU7+L4WziRU3afaoSme1ECAwEAAQ==
-----END PUBLIC KEY-----
```

####dn42-us-sea1

`dn42-us-sea1 will be replaced by dn42-us-sea2`

|||
|---|---|
|**Location**|Virpus, Seattle, United States|
|**Alias**|whirlpool|
|**Public Hostname**|dn42-us-sea1.burble.com|
|**Public IPv4 Address**|199.180.133.100|
|**Public IPv6 Address**|`IPv4 Only`|
|**Tunnel IPv4 Peer Address**|172.20.129.186/32|
|**Tunnel IPv6 Link Local**|fe80::42:2601:32:1/64|
|**Tunnel IPv6 ULA**|fd42:4242:2601:32::1/128|
|**IPSec Public Key**||
```
-----BEGIN PUBLIC KEY-----
MIICIjANBgkqhkiG9w0BAQEFAAOCAg8AMIICCgKCAgEA0oO9s5sEfeGW06zPb3XP
fv7w4NZIg0c/ieXtDYo/9Fe19X2dKBcueAYzmJjfxFq2vBS7kg/Oox/7gf0QxEFJ
jHmqBMUmPDsIDqGfT254Bac4LHT+Usy9vxLTdaDr/sDT0ZwnPlkntSW08d8S+jo5
cgA9xL9oSlzrimA/ARVQIk7ewqHJTHdmWh/xh2y1S2n5ehmvQnYANJcPQ++cjdc0
RRPa9HMwt6SlXv5SWsICyTLNpWQQPdQDr97axwezF/kDEenBjY7b1X9Jf+z8XPzP
/tQTggcagM/5q3nE9pTbQRnLWdTB4XSeTGMNiglG9lVVbzakPUQtVmEOl0eA7b9v
4Py5llIjSz/6wo9jezW2BtHtyMd/sne1woWFyJn+ZyCzLPGO0MG+wU3zH3pk9ht2
Q8SkoWvrx8zL/BCQDCPvpDJZ5RUYID+1HcAnP2RiHUxUXhzoAvn66YlA44kUXszz
sHkVcrWM+8vizqyziMBsnvhuyRTEHJNEcYeJ1kA2gjesRwrTWBmWBXKJ7C244GZm
iLBajGB+xgudaaY2yOs5StipcR8qYRpiX5e3wR6rdv+VJE5CAOdsn5I7F0se0e8/
KW1AH95Yd0/WTL95dYsBvZchSro+JR+WXC/SfvQHE4CIwxLv04TdK6jOQvftvwGF
HwMaGKVx+XSt8k4rg4kXOmMCAwEAAQ==
-----END PUBLIC KEY-----
```

####dn42-us-sea2
|||
|---|---|
|**Location**|Virmach, Seattle, United States|
|**Alias**|centaurus|
|**Public Hostname**|dn42-us-sea2.burble.com|
|**Public IPv4 Address**|96.8.121.205|
|**Public IPv6 Address**|`IPv4 Only`|
|**Tunnel IPv4 Peer Address**|172.20.129.170/32|
|**Tunnel IPv6 Link Local**|fe80::42:2601:2c:1/64|
|**Tunnel IPv6 ULA**|fd42:4242:2601:2c::1/128|
|**IPSec Public Key**||
```
-----BEGIN PUBLIC KEY-----
MIICIjANBgkqhkiG9w0BAQEFAAOCAg8AMIICCgKCAgEAzUqSdC4GyakicDPCNroL
kxaX1Fl+qmCBQn1dGhskjYhXeGS3bd/F4H2cJQ6GPsBBbIBO2nbfxOQ3RFXLysun
+Cu6aZ6X2/6VJP1U/09itNxRA49UH/JPDzRw7+Yukck+5DAIu06p6uMjcn1UiKcS
UQIse+9vdjvpoL72z7cEZLSD9dcNtvFU8F72QyDLr7+9Kk07oFcLv8rY+6tfW55S
BLpEw+yV9GuR2EwLHlhx85XAAR/8byqX241Be7lh8eMjCb+RZOEMmWzqvlSC6bhk
IJ+3m8kEjOxqrA8T4CWF5Ebh2CjLYmxgRtAxRdjiKWLcZdGZ6+StNR3OKKNYILw5
u5clNdKFCZerzYEJjCK6243YSI0lZX+CsgtnD0uS0htd/oKqGp+Mu0dPRA4piIrx
JKgJPHBRPFI+Uy/BD4WNSPebZ7UQrz62Av/CoEfsNXLnm2Y+jd0/xHTbYhn1NqRU
bQKMNg8eXgovv7aOXi9nAdCFrgsMomcgTlgeyT5w75PcP7JFZkbI4lyBrCuCEzWU
6wcWqqfRmTbntyeK9S6cMUKEXPvCiWSLte/6ic5OqusZWCeT2BpF2X3tOwji5tQt
SztbbPtKCRWRtAK7W1ZG+uJsOaVP8wvj9ed6Eb7T6r3pwltGdCiZKa2TMIE5wh3b
BtAERuwIBXJzCKNBQTbteZMCAwEAAQ==
-----END PUBLIC KEY-----
```


###Asia and Oceania
Internal ASN: AS4226010009

####dn42-sg-sin2

|||
|---|---|
|**Location**|OVH, Singapore|
|**Alias**|hoag|
|**Public Hostname**|dn42-sg-sin2.burble.com|
|**Public IPv4 Address**|139.99.97.88|
|**Public IPv6 Address**|2402:1f00:8000:800::8d2|
|**Tunnel IPv4 Peer Address**|172.20.129.181/32|
|**Tunnel IPv6 Link Local**|fe80::42:2601:37:1/64|
|**Tunnel IPv6 ULA**|fd42:4242:2601:37::1/128|
|**IPSec Public Key**||
```
-----BEGIN PUBLIC KEY-----
MIICIjANBgkqhkiG9w0BAQEFAAOCAg8AMIICCgKCAgEAnGI91/0rJZcd/x9eaGY8
WSIOdxs9VObYS8XS9J4IwjR8tOffKpgGGKh8Zm+jav+mma4sAi9r01TN+qrfu/Qs
9pehciodIKdTM1KkE48s9aksiHFidfT4aAJijNrztSVVw/+5re7i3Ms3wARd4jm2
Relxnk7o92QVIsppMXcwooCpG+AJ+Pd7Ho1kGVvC8nEXoebgCYrOf5Wf0bwLUjp6
bAjG+4zKcsVumFPd9v+kcXYP9E3O6fOpZdS0JMMusY24b59aNIkDKeXP7LrwJxbx
McOJPoum68UaQjmkda4kaa/4nkhKyUCM1WCEG1QKDnW6YukgNnZ3TVCmunp+D4g+
F/wPknnjI1TPkPSzsn68YCT3GNLvrjqIc1f9Za+76QUYpsNp+oIfqP7L6yi30oZa
323eQDSrjEIowRUiiyY10E6oDHcmGb0JrP8hM7tdAKh9m48hjLgRnBxX4hWKguCX
njRFR/ysWqgvrV+jc2XF6pO8kMO4H5v1CknBCgItmtR845GOBWoa8+fH55qhOY2J
W3eA7GdGY0yespYDXZeClzC6DgYXFPhFtdwV/rSkaYh6EAKo/zDNVn0ZXu8BebOv
4U+b4yTvObgjRYYiHipYZ+G5mjyEfmAPpJe+dfTFFKvNd8BRGoDoF8/k/2OtqSVJ
c1wdZ7aFPVA1IvfgZfD947MCAwEAAQ==
-----END PUBLIC KEY-----
```

####dn42-sg-sin3
|||
|---|---|
|**Location**|HostDoc, Singapore|
|**Alias**|starfish|
|**Public Hostname**|dn42-sg-sin3.burble.com|
|**Public IPv4 Address**|139.99.53.118|
|**Public IPv6 Address**|`IPv4 Only`|
|**Tunnel IPv4 Peer Address**|172.20.129.173/32|
|**Tunnel IPv6 Link Local**|fe80::42:2601:29:1/64|
|**Tunnel IPv6 ULA**|fd42:4242:2601:29::1/128|
|**IPSec Public Key**||
```
-----BEGIN PUBLIC KEY-----
MIICIjANBgkqhkiG9w0BAQEFAAOCAg8AMIICCgKCAgEA3e2qyaWaWqQJYK9cQ9vY
0i1FWQAAuMdYLMN+0mPNAdmam7ILG9X7WekktQV6tsGr32RtPQRt1M87D5jf3Y7q
IGJkkfdcVWr9AGh770F5flAF6IRFGGt26VqdPsxBkGm4kHuRfDNXLAzTVCoek+C5
9LgxOZ1m8josj9c8BgsAuxYR6bfIhFelo/1VxUcTUEzMULVfZCHcHkgZNpqtueS9
4NW7gmqr/BdUxOPDrmF7JZL1C/nd2J0o+kJw0luAlfgfazBDUSW2JM/CK4A3N7cF
mynY0iKfaFCQFFeaqKEy4NXPMwcBsGbCYRnkiPD7p178Wrc7Js8FkVajivcndAUc
mC2LD53yW+a21jGmsP1p9LiZ/5IAdlHLR2sTGFuz27gkGf0sVA3l3ZnP3J4ghmRX
d7gBEtR01T0h8Uytkn4JFlhte2c61p+lTpNOoFOT1MsjwWRke7VbHXWNOtBcSmem
CPaC9sIkUOshiX8tDphMEzydXS+e5fKm5Wb3wDBXoHzw2v756xuWOKFnyNU+wTNq
7nXBg9Tukxqb/Iv0D1bxuuBiyWYiDPNhDpAWjHqG6sFylNOGSv+S6JsmmoHGSook
k3eyji94hj40WbCaPqYYWQT4mU2+xDghWct6/OmuBCdfEHW1f9Jdd22ScXpLMoVJ
r/5Z7HX7+zLHodhwUXX1+hMCAwEAAQ==
-----END PUBLIC KEY-----
```


####dn42-au-syd1
|||
|---|---|
|**Location**|OVH, Sydney, Australia|
|**Alias**|mice|
|**Public Hostname**|dn42-au-syd1.burble.com|
|**Public IPv4 Address**|139.99.194.24|
|**Public IPv6 Address**|2402:1f00:8100:400::986|
|**Tunnel IPv4 Peer Address**|172.20.129.180/32|
|**Tunnel IPv6 Link Local**|fe80::42:2601:38:1/64|
|**Tunnel IPv6 ULA**|fd42:4242:2601:38::1/128|
|**IPSec Public Key**||
```
-----BEGIN PUBLIC KEY-----
MIICIjANBgkqhkiG9w0BAQEFAAOCAg8AMIICCgKCAgEAsQTtCXxzzQ/DAbsLbzB5
b34POcnmzrwzrgOH4Etya2M7BeOoIwXJ26gpDNeye7G8txQ8wj69QfcgKXmNupau
BFr4qXxx2YJJK3Ivzq3yzHCI8wM1mbJK+ppwgsLDSnzO4axW3uhTG/JaZzQBUFzV
DEYmEVfysON8izZ++axmGszKmVIER7DOJhSAKAXQTNT+H0f4ysplxUEldD8USqxN
R/rKhdUUfuYgRztmisUP+APCQ8QXkkTaiZ5Hfto8aO9FQiNuMPzrdSboSGzYWlii
gMlnQ5eVKVtq51MptwirvvWBajadi4VBL9K0Kj8ypPKF+kUKGDZqrenbudVhBgqr
XzZcp3M8L4neTN8C98B8qDTRjM1Wz11musCzTnVq+Qs4INK3XSNFjlNKr2yyugYR
AmAeqqv9HZOiVVyJYSa8VhUalAsnGLVN4NejL5XqX4dCDJjQDTN4iZ6uQ02iJIgQ
oU2FPnVf3SNaoUIDvEDGey3CHKn8+atcHG7wjBJacSVzTIKi0BTTacd3D+kka4bi
YzwDb+SdeJhLCC2+R1ljA/KTHRnjKXRi77KIFVmv+hFGVABAwJX7IRqjdza85qNI
qAdtGj89Ur34J/y6qvXDYcaaEXbGgFGVdZx412Ek4N258gOFLq1wmc181cr6U95/
L1JY/jIzwP4150MeNXgpXyECAwEAAQ==
-----END PUBLIC KEY-----
```

####dn42-vn-han1
|||
|---|---|
|**Location**|GreenCloudVPS, Hanoi, Vietnam|
|**Alias**|starburst|
|**Public Hostname**|dn42-vn-han1.burble.com|
|**Public IPv4 Address**|103.199.17.246|
|**Public IPv6 Address**|`IPv4 Only`|
|**Tunnel IPv4 Peer Address**|172.20.129.175/32|
|**Tunnel IPv6 Link Local**|fe80::42:2601:27:1/64|
|**Tunnel IPv6 ULA**|fd42:4242:2601:27::1/128|
|**IPSec Public Key**||
```
-----BEGIN PUBLIC KEY-----
MIICIjANBgkqhkiG9w0BAQEFAAOCAg8AMIICCgKCAgEAxAwXzq/mGmxPgxFf9eWK
DyUK29m32gMbuWsrhI0wS6kNtir0ejW0Wi2ALEdOfD7UbxNSaEtoEu4CFynO/+SV
tRN9h7uTZtD1Lb6RGFp25Wqvab7rfaYaUqqbYe+KShpdqNR0dg3wwZa/oYiAvGZ2
1Ne4TBnPc5KYWFMqfaULq9nEnE2a9RPN/TMDB1NzXF1wp88eVIzKaOGuflHblF8L
lSsqtJ8ZHYiH8i+CldbOREtMDZuFj0y0zJZ4VK8SY6xrmAEpSYqpG4+qE3OLu2Wh
JOrZKoCDkISUPS6JL9+Ajoy8ItPNNQE8KB4jAVUu6MO6KRRh3KDCcPWvxMfbXSej
L+t9lkogFKBc5XRrHONtrgL4mACqkZl+Z39CsS8HGAuc8EUfwxur91DIHOIiFZCr
HTcFmv0cZFRMaQKnTwGG1JAsxPZxLW5gFpdvrQFswfoTFt++3zLG2A3yhk9WCz3J
7f+xSk+7hD4WXtsVG8foGMYJj0Rps8uOtQupwhtVjdClx0+iO8UNUh0CshMm4W6l
S3a+HLSJntCo0YXQvYmdlikNDcT+DGtLUncwogVKxbbEzfRSsJmd5KGFn35Msg8O
6kfQzgZYXVUJVy3KSZd8dBA9pokkWVkO3p8YO9E47nyohN0PurDLLDjNvLifyw3f
4sP70m6oofj8wtKov/ovFO0CAwEAAQ==
-----END PUBLIC KEY-----
```

####dn42-jp-tyo1
|||
|---|---|
|**Location**|GreenCloudVPS, Tokyo, Japan|
|**Alias**|blackeye|
|**Public Hostname**|dn42-jp-tyo1.burble.com|
|**Public IPv4 Address**|172.93.221.20|
|**Public IPv6 Address**|2403:71c0:2000::d:8b97|
|**Tunnel IPv4 Peer Address**|172.20.129.182/32|
|**Tunnel IPv6 Link Local**|fe80::42:2601:3e:1/64|
|**Tunnel IPv6 ULA**|fd42:4242:2601:3e::1/128|
|**IPSec Public Key**||
```
-----BEGIN PUBLIC KEY-----
MIICIjANBgkqhkiG9w0BAQEFAAOCAg8AMIICCgKCAgEAo5vjsqvPSdeKgtI/YsRS
6cXEs1m0HwwDgNdVcqXGkfee4G6x7ispCgQIxZ51L7C61GeGYeqlpJx+8BijdaHu
7iKhAcjhMHYxBfYcXY0aY0biZFnDXEG1C8alB1rSpJdU2JX80s9nR3+Aqf17qmvo
XJzJv5c0itlcVzuZVw1FeRLXZgWVR6Kl9foqYEB7lfozzb80ap08f0yny1ECBp5a
4ePqsnxqUdSqLRD1zDEGZfb/1e4g6JUryfClrEg4UNESY0sYELAil53fISB6AXVr
uEg2GBWzGYGf4jo1mgUwdMAZzZW0jybQisr8jwn8KFGys/vZ0ZA1JocsLlNiaaE6
oxwvYRem8oQ11iCWlaFXjMtj3jhFCjCGljwukCfesPWvm8J1MCf/Oe/365CIl21D
zQFF0fWzBF2MarhxknWfx+U6gtXgZvEiMnI+DCX7dKxYLB4JKCNSXAlBJRxgAes2
2WMMn+RQsHzJAsHhtRmd3HyqjiQeo1OeZc/36sGvRsRbn4qPAQ1rR029zlZBJko7
qkEkXvn9cCGLrKJJiuepzOJOFAWqF1YO27xBdQGoTK4LoDtYomzl6T3K2N2F87xd
4J3Whdwku/h7i31VaRZyOzy1XP9/ZAXUSDelt3C2Timm+1y0italLuV/cj0/U4b/
kKadIt7G/1ss5h8vE3o7+y0CAwEAAQ==
-----END PUBLIC KEY-----
```

###Other Hosts

uk-bri1 - Bristol, UK  
uk-lon2 - Inception Hosting, London, UK

Sorry, these hosts are not currently open for public peering.